@@ -181,40 +181,3 @@ def download_video_if_wider(session, source: str, target: str, width: int) -> bo
     return True
 
 
-class Urls:
-    """ list of urls to download and to where """
-    def __init__(self, download_as_collecting=False):
-        """
-        constructor
-        :param download_as_collecting:
-        """
-        self.list = []
-        self.download_as_collecting = download_as_collecting
-
-    def add_url(self, source, target, session):
-        """
-        add url to the list
-        :param source:
-        :param target:
-        :param session:
-        :return:
-        """
-        self.list.append((source, target))
-        if self.download_as_collecting:
-            download_url(session, source=source, target=target)
-
-    def print(self):
-        """
-        print the list
-        :return:
-        """
-        for (source, target) in self.list:
-            print(source, target, sep="\t")
-
-    def download(self, session):
-        """
-        download the list
-        :return:
-        """
-        for (source, target) in self.list:
-            download_url(session, source=source, target=target)
