@@ -11,7 +11,7 @@ from pytconf.config import register_endpoint, register_function_group
 import pyscrapers.core.utils
 import pyscrapers.version
 from pyscrapers.configs import ConfigDebugRequests, ConfigCookiesSource, ConfigSiteId, ConfigPornhubSearch, \
-    ConfigYoutubeDl, ConfigDownload, ConfigLogging, ConfigPornhubUrl
+    ConfigYoutubeDl, ConfigDownload, ConfigLogging, ConfigUrl
 from pyscrapers.core.url_set import UrlSet
 from pyscrapers.workers.drumeo import get_number_of_pages, get_courses, get_course_details, get_course_urls, \
     download_course
@@ -144,6 +144,7 @@ def pornhub_stars_all_detailed():
     configs=[
         ConfigPornhubSearch,
         ConfigDownload,
+        ConfigYoutubeDl,
     ],
     group=GROUP_NAME_DEFAULT,
 )
@@ -158,8 +159,9 @@ def pornhub_download_search():
     configs=[
         ConfigDebugRequests,
         ConfigCookiesSource,
-        ConfigPornhubUrl,
+        ConfigUrl,
         ConfigDownload,
+        ConfigYoutubeDl,
     ],
     group=GROUP_NAME_DEFAULT,
 )
